package javax.swing.plaf.synth;

import java.awt.Graphics;
import java.beans.PropertyChangeEvent;
import javax.swing.text.JTextComponent;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.plaf.basic.BasicEditorPaneUI;

public class SynthEditorPaneUI extends BasicEditorPaneUI implements SynthUI
{
    private SynthStyle style;
    private Boolean localTrue;
    
    public SynthEditorPaneUI() {
        this.localTrue = Boolean.TRUE;
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthEditorPaneUI();
    }
    
    @Override
    protected void installDefaults() {
        super.installDefaults();
        JTextComponent component = this.getComponent();
        if (component.getClientProperty("JEditorPane.honorDisplayProperties") == null) {
            component.putClientProperty("JEditorPane.honorDisplayProperties", this.localTrue);
        }
        this.updateStyle(this.getComponent());
    }
    
    @Override
    protected void uninstallDefaults() {
        SynthContext context = this.getContext(this.getComponent(), 1);
        JTextComponent component = this.getComponent();
        component.putClientProperty("caretAspectRatio", null);
        this.style.uninstallDefaults(context);
        context.dispose();
        this.style = null;
        if (component.getClientProperty("JEditorPane.honorDisplayProperties") == this.localTrue) {
            component.putClientProperty("JEditorPane.honorDisplayProperties", Boolean.FALSE);
        }
        super.uninstallDefaults();
    }
    
    @Override
    protected void propertyChange(PropertyChangeEvent evt) {
        if (SynthLookAndFeel.shouldUpdateStyle(evt)) {
            this.updateStyle((JTextComponent)evt.getSource());
        }
        super.propertyChange(evt);
    }
    
    private void updateStyle(JTextComponent textComponent) {
        SynthContext context = this.getContext(textComponent, 1);
        SynthStyle style = this.style;
        this.style = SynthLookAndFeel.updateStyle(context, this);
        if (this.style != style) {
            SynthTextFieldUI.updateStyle(textComponent, context, this.getPropertyPrefix());
            if (style != null) {
                this.uninstallKeyboardActions();
                this.installKeyboardActions();
            }
        }
        context.dispose();
    }
    
    @Override
    public SynthContext getContext(JComponent component) {
        return this.getContext(component, this.getComponentState(component));
    }
    
    private SynthContext getContext(JComponent component, int n) {
        return SynthContext.getContext(component, this.style, n);
    }
    
    private int getComponentState(JComponent component) {
        return SynthLookAndFeel.getComponentState(component);
    }
    
    @Override
    public void update(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        SynthLookAndFeel.update(context, graphics);
        this.paintBackground(context, graphics, component);
        this.paint(context, graphics);
        context.dispose();
    }
    
    protected void paint(SynthContext synthContext, Graphics g) {
        super.paint(g, this.getComponent());
    }
    
    @Override
    protected void paintBackground(Graphics graphics) {
    }
    
    void paintBackground(SynthContext synthContext, Graphics graphics, JComponent component) {
        synthContext.getPainter().paintEditorPaneBackground(synthContext, graphics, 0, 0, component.getWidth(), component.getHeight());
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintEditorPaneBorder(synthContext, graphics, n, n2, n3, n4);
    }
}
